@@ -1,6 +1,8 @@
-use crate::handlebars_engine::deserialize_context::deserialize_context;
-use crate::out_model::class::caster_type::CasterType;
 use crate::out_model::class::Class;
+use crate::{
+    handlebars_engine::deserialize_context::deserialize_context,
+    out_model::class::generic_class::GenericClass,
+};
 use handlebars::{HelperDef, JsonValue, ScopedJson};
 
 #[allow(non_camel_case_types)]
@@ -16,8 +18,6 @@ impl HelperDef for has_spells {
         _: &mut ::handlebars::RenderContext<'reg, 'rc>,
     ) -> Result<::handlebars::ScopedJson<'reg, 'rc>, ::handlebars::RenderError> {
         let class = deserialize_context::<Class>(ctx)?.inner;
-        Ok(ScopedJson::Derived(JsonValue::Bool(
-            class.caster_type != CasterType::None
-        )))
+        Ok(ScopedJson::Derived(JsonValue::Bool(class.has_spells())))
     }
 }
