@@ -1,4 +1,4 @@
-use handlebars::{HelperDef, RenderError, ScopedJson, JsonValue};
+use handlebars::{HelperDef, JsonValue, RenderError, ScopedJson};
 use serde_json::Number;
 
 #[allow(non_camel_case_types)]
@@ -13,12 +13,15 @@ impl HelperDef for to_i {
         _: &'rc ::handlebars::Context,
         _: &mut ::handlebars::RenderContext<'reg, 'rc>,
     ) -> Result<::handlebars::ScopedJson<'reg, 'rc>, ::handlebars::RenderError> {
-        let a = h.param(0).ok_or_else(|| RenderError::new("param not found"))?.value().as_f64().ok_or_else(|| RenderError::new("not f64"))?;
+        let a = h
+            .param(0)
+            .ok_or_else(|| RenderError::new("param not found"))?
+            .value()
+            .as_f64()
+            .ok_or_else(|| RenderError::new("not f64"))?;
 
-
-
-        Ok(ScopedJson::Derived(
-            JsonValue::Number(Number::from(a.round() as i64))
-        ))
+        Ok(ScopedJson::Derived(JsonValue::Number(Number::from(
+            a.round() as i64,
+        ))))
     }
 }
