@@ -8,7 +8,7 @@ use resource::Resource;
 use starting_prof::StartingProf;
 use std::collections::{HashMap, HashSet};
 
-use self::subclasses::Subclasses;
+use self::{generic_class::GenericClass, subclasses::Subclasses};
 
 pub mod caster_type;
 pub mod equipment;
@@ -18,6 +18,7 @@ pub mod resource;
 pub mod starting_prof;
 pub mod subclass;
 pub mod subclasses;
+pub mod generic_class;
 
 #[derive(Debug, Clone, Deserialize, Serialize)]
 pub struct Class {
@@ -31,6 +32,32 @@ pub struct Class {
     pub hit_die: u8,
     pub starting_prof: StartingProf,
     pub equipment: Equipment,
-    pub features: Vec<Feature>,
+    pub features: HashMap<u8, Vec<Feature>>,
     pub subclasses: Subclasses,
 }
+
+impl GenericClass for Class {
+    fn name(&self) -> &str {
+        self.name.as_str()
+    }
+
+    fn flavour_text(&self) -> &str {
+        self.flavour_text.as_str()
+    }
+
+    fn start_cantrips_known(&self) -> Option<u8> {
+        self.start_cantrips_known.clone()
+    }
+
+    fn features(&self) -> &HashMap<u8, Vec<Feature>> {
+        &self.features
+    }
+
+    fn caster_type(&self) -> CasterType {
+        self.caster_type.clone()
+    }
+
+    fn class_resources(&self) -> &HashMap<String, Resource> {
+        &self.class_resources
+    }
+}
\ No newline at end of file
